/* network.h generated by valac 0.56.18-dirty, the Vala compiler, do not modify */

#ifndef __NETWORK_H__
#define __NETWORK_H__

#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include <wingpanel.h>
#include <glib-object.h>
#include <gmodule.h>
#include <gtk/gtk.h>
#include <NetworkManager.h>
#include <gio/gio.h>

G_BEGIN_DECLS

#define GETTEXT_PACKAGE "network-indicator"
#define LOCALEDIR "/usr/share/locale"
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define NETWORK_TYPE_INDICATOR (network_indicator_get_type ())
#define NETWORK_INDICATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), NETWORK_TYPE_INDICATOR, NetworkIndicator))
#define NETWORK_INDICATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), NETWORK_TYPE_INDICATOR, NetworkIndicatorClass))
#define NETWORK_IS_INDICATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), NETWORK_TYPE_INDICATOR))
#define NETWORK_IS_INDICATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), NETWORK_TYPE_INDICATOR))
#define NETWORK_INDICATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), NETWORK_TYPE_INDICATOR, NetworkIndicatorClass))

typedef struct _NetworkIndicator NetworkIndicator;
typedef struct _NetworkIndicatorClass NetworkIndicatorClass;
typedef struct _NetworkIndicatorPrivate NetworkIndicatorPrivate;
typedef enum  {
	RF_KILL_DEVICE_TYPE_ALL = 0,
	RF_KILL_DEVICE_TYPE_WLAN,
	RF_KILL_DEVICE_TYPE_BLUETOOTH,
	RF_KILL_DEVICE_TYPE_UWB,
	RF_KILL_DEVICE_TYPE_WIMAX,
	RF_KILL_DEVICE_TYPE_WMAN
} RFKillDeviceType;

#define TYPE_RF_KILL_DEVICE_TYPE (rf_kill_device_type_get_type ())

#define TYPE_RF_KILL_DEVICE (rf_kill_device_get_type ())
#define RF_KILL_DEVICE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_RF_KILL_DEVICE, RFKillDevice))
#define RF_KILL_DEVICE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_RF_KILL_DEVICE, RFKillDeviceClass))
#define IS_RF_KILL_DEVICE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_RF_KILL_DEVICE))
#define IS_RF_KILL_DEVICE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_RF_KILL_DEVICE))
#define RF_KILL_DEVICE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_RF_KILL_DEVICE, RFKillDeviceClass))

typedef struct _RFKillDevice RFKillDevice;
typedef struct _RFKillDeviceClass RFKillDeviceClass;
typedef struct _RFKillDevicePrivate RFKillDevicePrivate;

#define TYPE_RF_KILL_MANAGER (rf_kill_manager_get_type ())
#define RF_KILL_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_RF_KILL_MANAGER, RFKillManager))
#define RF_KILL_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_RF_KILL_MANAGER, RFKillManagerClass))
#define IS_RF_KILL_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_RF_KILL_MANAGER))
#define IS_RF_KILL_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_RF_KILL_MANAGER))
#define RF_KILL_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_RF_KILL_MANAGER, RFKillManagerClass))

typedef struct _RFKillManager RFKillManager;
typedef struct _RFKillManagerClass RFKillManagerClass;
typedef struct _RFKillManagerPrivate RFKillManagerPrivate;
typedef enum  {
	NETWORK_STATE_DISCONNECTED,
	NETWORK_STATE_WIRED_UNPLUGGED,
	NETWORK_STATE_DISCONNECTED_AIRPLANE_MODE,
	NETWORK_STATE_CONNECTED_WIRED,
	NETWORK_STATE_CONNECTED_WIFI_WEAK,
	NETWORK_STATE_CONNECTED_WIFI_OK,
	NETWORK_STATE_CONNECTED_WIFI_GOOD,
	NETWORK_STATE_CONNECTED_WIFI_EXCELLENT,
	NETWORK_STATE_CONNECTED_MOBILE_WEAK,
	NETWORK_STATE_CONNECTED_MOBILE_OK,
	NETWORK_STATE_CONNECTED_MOBILE_GOOD,
	NETWORK_STATE_CONNECTED_MOBILE_EXCELLENT,
	NETWORK_STATE_CONNECTING_WIFI,
	NETWORK_STATE_CONNECTING_MOBILE,
	NETWORK_STATE_CONNECTING_WIRED,
	NETWORK_STATE_FAILED,
	NETWORK_STATE_FAILED_WIFI,
	NETWORK_STATE_FAILED_MOBILE
} NetworkState;

#define NETWORK_TYPE_STATE (network_state_get_type ())

#define NETWORK_WIDGETS_TYPE_DISPLAY_WIDGET (network_widgets_display_widget_get_type ())
#define NETWORK_WIDGETS_DISPLAY_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), NETWORK_WIDGETS_TYPE_DISPLAY_WIDGET, NetworkWidgetsDisplayWidget))
#define NETWORK_WIDGETS_DISPLAY_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), NETWORK_WIDGETS_TYPE_DISPLAY_WIDGET, NetworkWidgetsDisplayWidgetClass))
#define NETWORK_WIDGETS_IS_DISPLAY_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), NETWORK_WIDGETS_TYPE_DISPLAY_WIDGET))
#define NETWORK_WIDGETS_IS_DISPLAY_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), NETWORK_WIDGETS_TYPE_DISPLAY_WIDGET))
#define NETWORK_WIDGETS_DISPLAY_WIDGET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), NETWORK_WIDGETS_TYPE_DISPLAY_WIDGET, NetworkWidgetsDisplayWidgetClass))

typedef struct _NetworkWidgetsDisplayWidget NetworkWidgetsDisplayWidget;
typedef struct _NetworkWidgetsDisplayWidgetClass NetworkWidgetsDisplayWidgetClass;
typedef struct _NetworkWidgetsDisplayWidgetPrivate NetworkWidgetsDisplayWidgetPrivate;

#define NETWORK_TYPE_WIDGET_NM_INTERFACE (network_widget_nm_interface_get_type ())
#define NETWORK_WIDGET_NM_INTERFACE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), NETWORK_TYPE_WIDGET_NM_INTERFACE, NetworkWidgetNMInterface))
#define NETWORK_WIDGET_NM_INTERFACE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), NETWORK_TYPE_WIDGET_NM_INTERFACE, NetworkWidgetNMInterfaceClass))
#define NETWORK_IS_WIDGET_NM_INTERFACE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), NETWORK_TYPE_WIDGET_NM_INTERFACE))
#define NETWORK_IS_WIDGET_NM_INTERFACE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), NETWORK_TYPE_WIDGET_NM_INTERFACE))
#define NETWORK_WIDGET_NM_INTERFACE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), NETWORK_TYPE_WIDGET_NM_INTERFACE, NetworkWidgetNMInterfaceClass))

typedef struct _NetworkWidgetNMInterface NetworkWidgetNMInterface;
typedef struct _NetworkWidgetNMInterfaceClass NetworkWidgetNMInterfaceClass;
typedef struct _NetworkWidgetNMInterfacePrivate NetworkWidgetNMInterfacePrivate;

#define NETWORK_TYPE_ETHER_INTERFACE (network_ether_interface_get_type ())
#define NETWORK_ETHER_INTERFACE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), NETWORK_TYPE_ETHER_INTERFACE, NetworkEtherInterface))
#define NETWORK_ETHER_INTERFACE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), NETWORK_TYPE_ETHER_INTERFACE, NetworkEtherInterfaceClass))
#define NETWORK_IS_ETHER_INTERFACE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), NETWORK_TYPE_ETHER_INTERFACE))
#define NETWORK_IS_ETHER_INTERFACE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), NETWORK_TYPE_ETHER_INTERFACE))
#define NETWORK_ETHER_INTERFACE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), NETWORK_TYPE_ETHER_INTERFACE, NetworkEtherInterfaceClass))

typedef struct _NetworkEtherInterface NetworkEtherInterface;
typedef struct _NetworkEtherInterfaceClass NetworkEtherInterfaceClass;
typedef struct _NetworkEtherInterfacePrivate NetworkEtherInterfacePrivate;

#define NETWORK_TYPE_MODEM_INTERFACE (network_modem_interface_get_type ())
#define NETWORK_MODEM_INTERFACE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), NETWORK_TYPE_MODEM_INTERFACE, NetworkModemInterface))
#define NETWORK_MODEM_INTERFACE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), NETWORK_TYPE_MODEM_INTERFACE, NetworkModemInterfaceClass))
#define NETWORK_IS_MODEM_INTERFACE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), NETWORK_TYPE_MODEM_INTERFACE))
#define NETWORK_IS_MODEM_INTERFACE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), NETWORK_TYPE_MODEM_INTERFACE))
#define NETWORK_MODEM_INTERFACE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), NETWORK_TYPE_MODEM_INTERFACE, NetworkModemInterfaceClass))

typedef struct _NetworkModemInterface NetworkModemInterface;
typedef struct _NetworkModemInterfaceClass NetworkModemInterfaceClass;
typedef struct _NetworkModemInterfacePrivate NetworkModemInterfacePrivate;

#define NETWORK_WIDGETS_TYPE_POPOVER_WIDGET (network_widgets_popover_widget_get_type ())
#define NETWORK_WIDGETS_POPOVER_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), NETWORK_WIDGETS_TYPE_POPOVER_WIDGET, NetworkWidgetsPopoverWidget))
#define NETWORK_WIDGETS_POPOVER_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), NETWORK_WIDGETS_TYPE_POPOVER_WIDGET, NetworkWidgetsPopoverWidgetClass))
#define NETWORK_WIDGETS_IS_POPOVER_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), NETWORK_WIDGETS_TYPE_POPOVER_WIDGET))
#define NETWORK_WIDGETS_IS_POPOVER_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), NETWORK_WIDGETS_TYPE_POPOVER_WIDGET))
#define NETWORK_WIDGETS_POPOVER_WIDGET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), NETWORK_WIDGETS_TYPE_POPOVER_WIDGET, NetworkWidgetsPopoverWidgetClass))

typedef struct _NetworkWidgetsPopoverWidget NetworkWidgetsPopoverWidget;
typedef struct _NetworkWidgetsPopoverWidgetClass NetworkWidgetsPopoverWidgetClass;
typedef struct _NetworkWidgetsPopoverWidgetPrivate NetworkWidgetsPopoverWidgetPrivate;

#define NETWORK_TYPE_SETTINGS_TOGGLE (network_settings_toggle_get_type ())
#define NETWORK_SETTINGS_TOGGLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), NETWORK_TYPE_SETTINGS_TOGGLE, NetworkSettingsToggle))
#define NETWORK_SETTINGS_TOGGLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), NETWORK_TYPE_SETTINGS_TOGGLE, NetworkSettingsToggleClass))
#define NETWORK_IS_SETTINGS_TOGGLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), NETWORK_TYPE_SETTINGS_TOGGLE))
#define NETWORK_IS_SETTINGS_TOGGLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), NETWORK_TYPE_SETTINGS_TOGGLE))
#define NETWORK_SETTINGS_TOGGLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), NETWORK_TYPE_SETTINGS_TOGGLE, NetworkSettingsToggleClass))

typedef struct _NetworkSettingsToggle NetworkSettingsToggle;
typedef struct _NetworkSettingsToggleClass NetworkSettingsToggleClass;
typedef struct _NetworkSettingsTogglePrivate NetworkSettingsTogglePrivate;

#define NETWORK_TYPE_VPN_INTERFACE (network_vpn_interface_get_type ())
#define NETWORK_VPN_INTERFACE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), NETWORK_TYPE_VPN_INTERFACE, NetworkVpnInterface))
#define NETWORK_VPN_INTERFACE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), NETWORK_TYPE_VPN_INTERFACE, NetworkVpnInterfaceClass))
#define NETWORK_IS_VPN_INTERFACE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), NETWORK_TYPE_VPN_INTERFACE))
#define NETWORK_IS_VPN_INTERFACE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), NETWORK_TYPE_VPN_INTERFACE))
#define NETWORK_VPN_INTERFACE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), NETWORK_TYPE_VPN_INTERFACE, NetworkVpnInterfaceClass))

typedef struct _NetworkVpnInterface NetworkVpnInterface;
typedef struct _NetworkVpnInterfaceClass NetworkVpnInterfaceClass;
typedef struct _NetworkVpnInterfacePrivate NetworkVpnInterfacePrivate;

#define NETWORK_TYPE_VPN_MENU_ITEM (network_vpn_menu_item_get_type ())
#define NETWORK_VPN_MENU_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), NETWORK_TYPE_VPN_MENU_ITEM, NetworkVpnMenuItem))
#define NETWORK_VPN_MENU_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), NETWORK_TYPE_VPN_MENU_ITEM, NetworkVpnMenuItemClass))
#define NETWORK_IS_VPN_MENU_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), NETWORK_TYPE_VPN_MENU_ITEM))
#define NETWORK_IS_VPN_MENU_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), NETWORK_TYPE_VPN_MENU_ITEM))
#define NETWORK_VPN_MENU_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), NETWORK_TYPE_VPN_MENU_ITEM, NetworkVpnMenuItemClass))

typedef struct _NetworkVpnMenuItem NetworkVpnMenuItem;
typedef struct _NetworkVpnMenuItemClass NetworkVpnMenuItemClass;
typedef struct _NetworkVpnMenuItemPrivate NetworkVpnMenuItemPrivate;

#define NETWORK_TYPE_WIFI_INTERFACE (network_wifi_interface_get_type ())
#define NETWORK_WIFI_INTERFACE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), NETWORK_TYPE_WIFI_INTERFACE, NetworkWifiInterface))
#define NETWORK_WIFI_INTERFACE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), NETWORK_TYPE_WIFI_INTERFACE, NetworkWifiInterfaceClass))
#define NETWORK_IS_WIFI_INTERFACE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), NETWORK_TYPE_WIFI_INTERFACE))
#define NETWORK_IS_WIFI_INTERFACE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), NETWORK_TYPE_WIFI_INTERFACE))
#define NETWORK_WIFI_INTERFACE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), NETWORK_TYPE_WIFI_INTERFACE, NetworkWifiInterfaceClass))

typedef struct _NetworkWifiInterface NetworkWifiInterface;
typedef struct _NetworkWifiInterfaceClass NetworkWifiInterfaceClass;
typedef struct _NetworkWifiInterfacePrivate NetworkWifiInterfacePrivate;

#define NETWORK_TYPE_WIFI_MENU_ITEM (network_wifi_menu_item_get_type ())
#define NETWORK_WIFI_MENU_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), NETWORK_TYPE_WIFI_MENU_ITEM, NetworkWifiMenuItem))
#define NETWORK_WIFI_MENU_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), NETWORK_TYPE_WIFI_MENU_ITEM, NetworkWifiMenuItemClass))
#define NETWORK_IS_WIFI_MENU_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), NETWORK_TYPE_WIFI_MENU_ITEM))
#define NETWORK_IS_WIFI_MENU_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), NETWORK_TYPE_WIFI_MENU_ITEM))
#define NETWORK_WIFI_MENU_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), NETWORK_TYPE_WIFI_MENU_ITEM, NetworkWifiMenuItemClass))

typedef struct _NetworkWifiMenuItem NetworkWifiMenuItem;
typedef struct _NetworkWifiMenuItemClass NetworkWifiMenuItemClass;
typedef struct _NetworkWifiMenuItemPrivate NetworkWifiMenuItemPrivate;

struct _NetworkIndicator {
	WingpanelIndicator parent_instance;
	NetworkIndicatorPrivate * priv;
};

struct _NetworkIndicatorClass {
	WingpanelIndicatorClass parent_class;
};

struct _RFKillDevice {
	GTypeInstance parent_instance;
	volatile int ref_count;
	RFKillDevicePrivate * priv;
	RFKillManager* manager;
	guint32 idx;
	RFKillDeviceType _device_type;
	gboolean _software_lock;
	gboolean _hardware_lock;
};

struct _RFKillDeviceClass {
	GTypeClass parent_class;
	void (*finalize) (RFKillDevice *self);
};

struct _RFKillManager {
	GObject parent_instance;
	RFKillManagerPrivate * priv;
	gint fd;
};

struct _RFKillManagerClass {
	GObjectClass parent_class;
};

struct _NetworkWidgetsDisplayWidget {
	GtkBox parent_instance;
	NetworkWidgetsDisplayWidgetPrivate * priv;
};

struct _NetworkWidgetsDisplayWidgetClass {
	GtkBoxClass parent_class;
};

struct _NetworkWidgetNMInterface {
	GtkBox parent_instance;
	NetworkWidgetNMInterfacePrivate * priv;
};

struct _NetworkWidgetNMInterfaceClass {
	GtkBoxClass parent_class;
};

struct _NetworkEtherInterface {
	NetworkWidgetNMInterface parent_instance;
	NetworkEtherInterfacePrivate * priv;
};

struct _NetworkEtherInterfaceClass {
	NetworkWidgetNMInterfaceClass parent_class;
};

struct _NetworkModemInterface {
	NetworkWidgetNMInterface parent_instance;
	NetworkModemInterfacePrivate * priv;
};

struct _NetworkModemInterfaceClass {
	NetworkWidgetNMInterfaceClass parent_class;
};

struct _NetworkWidgetsPopoverWidget {
	GtkBox parent_instance;
	NetworkWidgetsPopoverWidgetPrivate * priv;
};

struct _NetworkWidgetsPopoverWidgetClass {
	GtkBoxClass parent_class;
};

struct _NetworkSettingsToggle {
	GtkBox parent_instance;
	NetworkSettingsTogglePrivate * priv;
};

struct _NetworkSettingsToggleClass {
	GtkBoxClass parent_class;
};

struct _NetworkVpnInterface {
	NetworkWidgetNMInterface parent_instance;
	NetworkVpnInterfacePrivate * priv;
};

struct _NetworkVpnInterfaceClass {
	NetworkWidgetNMInterfaceClass parent_class;
};

struct _NetworkVpnMenuItem {
	GtkFlowBoxChild parent_instance;
	NetworkVpnMenuItemPrivate * priv;
	GCancellable* cancellable;
};

struct _NetworkVpnMenuItemClass {
	GtkFlowBoxChildClass parent_class;
};

struct _NetworkWifiInterface {
	NetworkWidgetNMInterface parent_instance;
	NetworkWifiInterfacePrivate * priv;
	NMDeviceWifi* wifi_device;
};

struct _NetworkWifiInterfaceClass {
	NetworkWidgetNMInterfaceClass parent_class;
};

struct _NetworkWifiMenuItem {
	GtkListBoxRow parent_instance;
	NetworkWifiMenuItemPrivate * priv;
};

struct _NetworkWifiMenuItemClass {
	GtkListBoxRowClass parent_class;
};

VALA_EXTERN GType network_indicator_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (NetworkIndicator, g_object_unref)
VALA_EXTERN NetworkIndicator* network_indicator_new (gboolean is_in_session);
VALA_EXTERN NetworkIndicator* network_indicator_construct (GType object_type,
                                               gboolean is_in_session);
VALA_EXTERN gboolean network_indicator_get_is_in_session (NetworkIndicator* self);
VALA_EXTERN void network_indicator_set_is_in_session (NetworkIndicator* self,
                                          gboolean value);
VALA_EXTERN WingpanelIndicator* get_indicator (GModule* module,
                                   WingpanelIndicatorManagerServerType server_type);
VALA_EXTERN GType rf_kill_device_type_get_type (void) G_GNUC_CONST ;
VALA_EXTERN gpointer rf_kill_device_ref (gpointer instance);
VALA_EXTERN void rf_kill_device_unref (gpointer instance);
VALA_EXTERN GParamSpec* param_spec_rf_kill_device (const gchar* name,
                                       const gchar* nick,
                                       const gchar* blurb,
                                       GType object_type,
                                       GParamFlags flags);
VALA_EXTERN void value_set_rf_kill_device (GValue* value,
                               gpointer v_object);
VALA_EXTERN void value_take_rf_kill_device (GValue* value,
                                gpointer v_object);
VALA_EXTERN gpointer value_get_rf_kill_device (const GValue* value);
VALA_EXTERN GType rf_kill_device_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (RFKillDevice, rf_kill_device_unref)
VALA_EXTERN GType rf_kill_manager_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (RFKillManager, g_object_unref)
VALA_EXTERN gboolean rf_kill_device_get_software_lock (RFKillDevice* self);
VALA_EXTERN void rf_kill_device_set_software_lock (RFKillDevice* self,
                                       gboolean value);
VALA_EXTERN gboolean rf_kill_device_get_hardware_lock (RFKillDevice* self);
VALA_EXTERN RFKillDeviceType rf_kill_device_get_device_type (RFKillDevice* self);
VALA_EXTERN RFKillManager* rf_kill_manager_new (void);
VALA_EXTERN RFKillManager* rf_kill_manager_construct (GType object_type);
VALA_EXTERN void rf_kill_manager_open (RFKillManager* self);
VALA_EXTERN GList* rf_kill_manager_get_devices (RFKillManager* self);
VALA_EXTERN void rf_kill_manager_set_software_lock (RFKillManager* self,
                                        RFKillDeviceType type,
                                        gboolean lock_enabled);
VALA_EXTERN gboolean rf_kill_manager_get_airplane_mode (RFKillManager* self);
VALA_EXTERN void rf_kill_manager_set_airplane_mode (RFKillManager* self,
                                        gboolean value);
VALA_EXTERN GType network_state_get_type (void) G_GNUC_CONST ;
VALA_EXTERN gint network_state_get_priority (NetworkState self);
VALA_EXTERN GType network_widgets_display_widget_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (NetworkWidgetsDisplayWidget, g_object_unref)
VALA_EXTERN void network_widgets_display_widget_update_state (NetworkWidgetsDisplayWidget* self,
                                                  NetworkState state,
                                                  gboolean secure,
                                                  const gchar* extra_info);
VALA_EXTERN NetworkWidgetsDisplayWidget* network_widgets_display_widget_new (void);
VALA_EXTERN NetworkWidgetsDisplayWidget* network_widgets_display_widget_construct (GType object_type);
VALA_EXTERN GType network_widget_nm_interface_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (NetworkWidgetNMInterface, g_object_unref)
VALA_EXTERN GType network_ether_interface_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (NetworkEtherInterface, g_object_unref)
VALA_EXTERN NetworkEtherInterface* network_ether_interface_new (NMClient* nm_client,
                                                    NMDevice* _device);
VALA_EXTERN NetworkEtherInterface* network_ether_interface_construct (GType object_type,
                                                          NMClient* nm_client,
                                                          NMDevice* _device);
VALA_EXTERN GType network_modem_interface_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (NetworkModemInterface, g_object_unref)
VALA_EXTERN NetworkModemInterface* network_modem_interface_new (NMClient* nm_client,
                                                    NMDevice* _device);
VALA_EXTERN NetworkModemInterface* network_modem_interface_construct (GType object_type,
                                                          NMClient* nm_client,
                                                          NMDevice* _device);
VALA_EXTERN void network_modem_interface_prepare (NetworkModemInterface* self,
                                      GAsyncReadyCallback _callback_,
                                      gpointer _user_data_);
VALA_EXTERN void network_modem_interface_prepare_finish (NetworkModemInterface* self,
                                             GAsyncResult* _res_);
VALA_EXTERN const gchar* network_modem_interface_get_extra_info (NetworkModemInterface* self);
VALA_EXTERN guint32 network_modem_interface_get_signal_quality (NetworkModemInterface* self);
VALA_EXTERN GType network_widgets_popover_widget_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (NetworkWidgetsPopoverWidget, g_object_unref)
VALA_EXTERN NetworkWidgetsPopoverWidget* network_widgets_popover_widget_new (gboolean is_in_session);
VALA_EXTERN NetworkWidgetsPopoverWidget* network_widgets_popover_widget_construct (GType object_type,
                                                                       gboolean is_in_session);
VALA_EXTERN void network_widgets_popover_widget_opened (NetworkWidgetsPopoverWidget* self);
VALA_EXTERN void network_widgets_popover_widget_closed (NetworkWidgetsPopoverWidget* self);
VALA_EXTERN NMClient* network_widgets_popover_widget_get_nm_client (NetworkWidgetsPopoverWidget* self);
VALA_EXTERN GList* network_widgets_popover_widget_get_network_interface (NetworkWidgetsPopoverWidget* self);
VALA_EXTERN gboolean network_widgets_popover_widget_get_secure (NetworkWidgetsPopoverWidget* self);
VALA_EXTERN const gchar* network_widgets_popover_widget_get_extra_info (NetworkWidgetsPopoverWidget* self);
VALA_EXTERN NetworkState network_widgets_popover_widget_get_state (NetworkWidgetsPopoverWidget* self);
VALA_EXTERN gboolean network_widgets_popover_widget_get_is_in_session (NetworkWidgetsPopoverWidget* self);
VALA_EXTERN GType network_settings_toggle_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (NetworkSettingsToggle, g_object_unref)
VALA_EXTERN NetworkSettingsToggle* network_settings_toggle_new (void);
VALA_EXTERN NetworkSettingsToggle* network_settings_toggle_construct (GType object_type);
VALA_EXTERN const gchar* network_settings_toggle_get_action_name (NetworkSettingsToggle* self);
VALA_EXTERN void network_settings_toggle_set_action_name (NetworkSettingsToggle* self,
                                              const gchar* value);
VALA_EXTERN const gchar* network_settings_toggle_get_icon_name (NetworkSettingsToggle* self);
VALA_EXTERN void network_settings_toggle_set_icon_name (NetworkSettingsToggle* self,
                                            const gchar* value);
VALA_EXTERN const gchar* network_settings_toggle_get_text (NetworkSettingsToggle* self);
VALA_EXTERN void network_settings_toggle_set_text (NetworkSettingsToggle* self,
                                       const gchar* value);
VALA_EXTERN const gchar* network_settings_toggle_get_settings_uri (NetworkSettingsToggle* self);
VALA_EXTERN void network_settings_toggle_set_settings_uri (NetworkSettingsToggle* self,
                                               const gchar* value);
VALA_EXTERN GType network_vpn_interface_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (NetworkVpnInterface, g_object_unref)
VALA_EXTERN NetworkVpnInterface* network_vpn_interface_new (NMClient* nm_client);
VALA_EXTERN NetworkVpnInterface* network_vpn_interface_construct (GType object_type,
                                                      NMClient* nm_client);
VALA_EXTERN NMClient* network_vpn_interface_get_nm_client (NetworkVpnInterface* self);
VALA_EXTERN GType network_vpn_menu_item_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (NetworkVpnMenuItem, g_object_unref)
VALA_EXTERN NetworkVpnMenuItem* network_vpn_menu_item_new (NMRemoteConnection* remote_connection);
VALA_EXTERN NetworkVpnMenuItem* network_vpn_menu_item_construct (GType object_type,
                                                     NMRemoteConnection* remote_connection);
VALA_EXTERN NMRemoteConnection* network_vpn_menu_item_get_remote_connection (NetworkVpnMenuItem* self);
VALA_EXTERN NMActiveConnection* network_vpn_menu_item_get_vpn_connection (NetworkVpnMenuItem* self);
VALA_EXTERN void network_vpn_menu_item_set_vpn_connection (NetworkVpnMenuItem* self,
                                               NMActiveConnection* value);
VALA_EXTERN NetworkWidgetNMInterface* network_widget_nm_interface_construct (GType object_type);
VALA_EXTERN NMDevice* network_widget_nm_interface_get_device (NetworkWidgetNMInterface* self);
VALA_EXTERN void network_widget_nm_interface_set_device (NetworkWidgetNMInterface* self,
                                             NMDevice* value);
VALA_EXTERN NetworkState network_widget_nm_interface_get_state (NetworkWidgetNMInterface* self);
VALA_EXTERN void network_widget_nm_interface_set_state (NetworkWidgetNMInterface* self,
                                            NetworkState value);
VALA_EXTERN const gchar* network_widget_nm_interface_get_display_title (NetworkWidgetNMInterface* self);
VALA_EXTERN void network_widget_nm_interface_set_display_title (NetworkWidgetNMInterface* self,
                                                    const gchar* value);
VALA_EXTERN GtkSeparator* network_widget_nm_interface_get_sep (NetworkWidgetNMInterface* self);
VALA_EXTERN GType network_wifi_interface_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (NetworkWifiInterface, g_object_unref)
VALA_EXTERN NetworkWifiInterface* network_wifi_interface_new (NMClient* nm_client,
                                                  NMDevice* _device);
VALA_EXTERN NetworkWifiInterface* network_wifi_interface_construct (GType object_type,
                                                        NMClient* nm_client,
                                                        NMDevice* _device);
VALA_EXTERN void network_wifi_interface_start_scanning (NetworkWifiInterface* self);
VALA_EXTERN void network_wifi_interface_cancel_scanning (NetworkWifiInterface* self);
VALA_EXTERN void network_wifi_interface_connect_to_hidden (NetworkWifiInterface* self);
VALA_EXTERN NMClient* network_wifi_interface_get_nm_client (NetworkWifiInterface* self);
VALA_EXTERN gboolean network_wifi_interface_get_hidden_sensitivity (NetworkWifiInterface* self);
VALA_EXTERN void network_wifi_interface_set_hidden_sensitivity (NetworkWifiInterface* self,
                                                    gboolean value);
VALA_EXTERN const gchar* network_wifi_interface_get_active_ap_name (NetworkWifiInterface* self);
VALA_EXTERN GType network_wifi_menu_item_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (NetworkWifiMenuItem, g_object_unref)
VALA_EXTERN NetworkWifiMenuItem* network_wifi_menu_item_new (NMAccessPoint* ap,
                                                 GtkRadioButton* blank_radio);
VALA_EXTERN NetworkWifiMenuItem* network_wifi_menu_item_construct (GType object_type,
                                                       NMAccessPoint* ap,
                                                       GtkRadioButton* blank_radio);
VALA_EXTERN void network_wifi_menu_item_add_ap (NetworkWifiMenuItem* self,
                                    NMAccessPoint* ap);
VALA_EXTERN gboolean network_wifi_menu_item_remove_ap (NetworkWifiMenuItem* self,
                                           NMAccessPoint* ap);
VALA_EXTERN NMAccessPoint* network_wifi_menu_item_get_ap (NetworkWifiMenuItem* self);
VALA_EXTERN NMDeviceState network_wifi_menu_item_get_state (NetworkWifiMenuItem* self);
VALA_EXTERN void network_wifi_menu_item_set_state (NetworkWifiMenuItem* self,
                                       NMDeviceState value);
VALA_EXTERN GBytes* network_wifi_menu_item_get_ssid (NetworkWifiMenuItem* self);
VALA_EXTERN guint8 network_wifi_menu_item_get_strength (NetworkWifiMenuItem* self);
VALA_EXTERN void network_wifi_menu_item_set_active (NetworkWifiMenuItem* self,
                                        gboolean value);

G_END_DECLS

#endif
